## Description

<!-- Describe the changes you made in this PR. -->

## Checklist

<!-- Make sure all items below are checked before submitting the PR. -->

- [ ] I have run the tests locally with `make install-dev` and `make test`
- [ ] I have updated the `README.md` if my changes affected it
- [ ] I have updated the package version in `linkup/_version.py` and `pyproject.toml` if I plan on creating a new release
